@@ -6,7 +6,7 @@ test_that("Total de linhas e colunas", {
   expect_equal(ncol(df), 3)
 })
 
-df <- gun_seizure_historical(by = 'police_station_area')
+df <- gun_seizure_historical(by = 'cisp')
 
 test_that("Total de linhas e colunas", {
   expect_gt(nrow(df), 6205)
